@@ -8,7 +8,7 @@
 #include "fstring.h"
 #include "libutil/cxx/utf8_util.h"
 
-#ifdef  __cplusplus
+#ifdef __cplusplus
 extern "C" {
 #endif
 
@@ -52,35 +52,51 @@ struct rspamd_url_tag {
 	struct rspamd_url_tag *prev, *next;
 };
 
-
+struct rspamd_url_ext;
+/**
+ * URL structure
+ */
 struct rspamd_url {
-	gchar *string;
-	gchar *raw;
+	char *string;
+	char *raw;
+	struct rspamd_url_ext *ext;
 
+	uint32_t flags;
+
+	uint8_t protocol;
+	uint8_t protocollen;
+
+	uint16_t hostshift;
+	uint16_t datashift;
+	uint16_t queryshift;
+	uint16_t fragmentshift;
+	uint16_t tldshift;
+	guint16 usershift;
+	guint16 userlen;
+
+	uint16_t hostlen;
+	uint16_t datalen;
+	uint16_t querylen;
+	uint16_t fragmentlen;
+	uint16_t tldlen;
+	uint16_t count;
+	uint16_t urllen;
+	uint16_t rawlen;
+
+	/* Absolute order of the URL in a message */
+	uint16_t order;
+	/* Order of the URL in a specific part of message */
+	uint16_t part_order;
+};
+
+/**
+ * Rarely used url fields
+ */
+struct rspamd_url_ext {
 	gchar *visible_part;
 	struct rspamd_url *linked_url;
 
-	guint32 flags;
-
-	guint8 protocol;
-	guint8 protocollen;
-
 	guint16 port;
-	guint16 usershift;
-	guint16 hostshift;
-	guint16 datashift;
-	guint16 queryshift;
-	guint16 fragmentshift;
-	guint16 tldshift;
-	guint16 userlen;
-	guint16 hostlen;
-	guint16 datalen;
-	guint16 querylen;
-	guint16 fragmentlen;
-	guint16 tldlen;
-	guint16 count;
-	guint16 urllen;
-	guint16 rawlen;
 };
 
 #define rspamd_url_user(u) ((u)->userlen > 0 ? (u)->string + (u)->usershift : NULL)
@@ -96,10 +112,10 @@ struct rspamd_url {
 
 enum uri_errno {
 	URI_ERRNO_OK = 0,           /* Parsing went well */
-	URI_ERRNO_EMPTY,        /* The URI string was empty */
+	URI_ERRNO_EMPTY,            /* The URI string was empty */
 	URI_ERRNO_INVALID_PROTOCOL, /* No protocol was found */
 	URI_ERRNO_INVALID_PORT,     /* Port number is bad */
-	URI_ERRNO_BAD_ENCODING, /* Bad characters encoding */
+	URI_ERRNO_BAD_ENCODING,     /* Bad characters encoding */
 	URI_ERRNO_BAD_FORMAT,
 	URI_ERRNO_TLD_MISSING,
 	URI_ERRNO_HOST_MISSING,
@@ -145,6 +161,7 @@ void rspamd_url_deinit(void);
 void rspamd_url_text_extract(rspamd_mempool_t *pool,
 							 struct rspamd_task *task,
 							 struct rspamd_mime_text_part *part,
+							 uint16_t *cur_order,
 							 enum rspamd_url_find_type how);
 
 /*
@@ -294,8 +311,8 @@ bool rspamd_url_flag_from_string(const gchar *str, gint *flag);
 const gchar *rspamd_url_flag_to_string(int flag);
 
 /* Defines sets of urls indexed by url as is */
-KHASH_DECLARE (rspamd_url_hash, struct rspamd_url *, char);
-KHASH_DECLARE (rspamd_url_host_hash, struct rspamd_url *, char);
+KHASH_DECLARE(rspamd_url_hash, struct rspamd_url *, char);
+KHASH_DECLARE(rspamd_url_host_hash, struct rspamd_url *, char);
 
 /* Convenience functions for url sets */
 /**
@@ -304,7 +321,7 @@ KHASH_DECLARE (rspamd_url_host_hash, struct rspamd_url *, char);
  * @param u
  * @return true if a new url has been added
  */
-bool rspamd_url_set_add_or_increase(khash_t (rspamd_url_hash) *set,
+bool rspamd_url_set_add_or_increase(khash_t(rspamd_url_hash) * set,
 									struct rspamd_url *u,
 									bool enforce_replace);
 
@@ -314,7 +331,7 @@ bool rspamd_url_set_add_or_increase(khash_t (rspamd_url_hash) *set,
  * @param u
  * @return
  */
-struct rspamd_url *rspamd_url_set_add_or_return(khash_t (rspamd_url_hash) *set,
+struct rspamd_url *rspamd_url_set_add_or_return(khash_t(rspamd_url_hash) * set,
 												struct rspamd_url *u);
 /**
  * Helper for url host set
@@ -322,7 +339,7 @@ struct rspamd_url *rspamd_url_set_add_or_return(khash_t (rspamd_url_hash) *set,
  * @param u
  * @return
  */
-bool rspamd_url_host_set_add(khash_t (rspamd_url_host_hash) *set,
+bool rspamd_url_host_set_add(khash_t(rspamd_url_host_hash) * set,
 							 struct rspamd_url *u);
 /**
  * Checks if a url is in set
@@ -330,9 +347,9 @@ bool rspamd_url_host_set_add(khash_t (rspamd_url_host_hash) *set,
  * @param u
  * @return
  */
-bool rspamd_url_set_has(khash_t (rspamd_url_hash) *set, struct rspamd_url *u);
+bool rspamd_url_set_has(khash_t(rspamd_url_hash) * set, struct rspamd_url *u);
 
-bool rspamd_url_host_set_has(khash_t (rspamd_url_host_hash) *set, struct rspamd_url *u);
+bool rspamd_url_host_set_has(khash_t(rspamd_url_host_hash) * set, struct rspamd_url *u);
 
 /**
  * Compares two urls (similar to C comparison functions) lexicographically
@@ -350,6 +367,41 @@ int rspamd_url_cmp(const struct rspamd_url *u1, const struct rspamd_url *u2);
  */
 int rspamd_url_cmp_qsort(const void *u1, const void *u2);
 
+/**
+ * Returns a port for some url
+ * @param u
+ * @return
+ */
+static RSPAMD_PURE_FUNCTION inline uint16_t rspamd_url_get_port(struct rspamd_url *u)
+{
+	if ((u->flags & RSPAMD_URL_FLAG_HAS_PORT) && u->ext) {
+		return u->ext->port;
+	}
+	else {
+		/* Assume standard port */
+		if (u->protocol == PROTOCOL_HTTPS) {
+			return 443;
+		}
+		else {
+			return 80;
+		}
+	}
+}
+
+/**
+ * Returns a port for some url if it is set
+ * @param u
+ * @return
+ */
+static RSPAMD_PURE_FUNCTION inline uint16_t rspamd_url_get_port_if_special(struct rspamd_url *u)
+{
+	if ((u->flags & RSPAMD_URL_FLAG_HAS_PORT) && u->ext) {
+		return u->ext->port;
+	}
+
+	return 0;
+}
+
 /**
  * Normalize unicode input and set out url flags as appropriate
  * @param pool
@@ -358,20 +410,20 @@ int rspamd_url_cmp_qsort(const void *u1, const void *u2);
  * @param url_flags_out (must be just a var with no dereference)
  */
 #define rspamd_url_normalise_propagate_flags(pool, input, len_out, url_flags_out) \
-  do {                                                                            \
-     enum rspamd_normalise_result norm_res;                                       \
-     norm_res = rspamd_normalise_unicode_inplace((input), (len_out));     \
-     if (norm_res & RSPAMD_UNICODE_NORM_UNNORMAL) {                               \
-       url_flags_out |= RSPAMD_URL_FLAG_UNNORMALISED;                             \
-     }                                                                            \
-     if (norm_res & RSPAMD_UNICODE_NORM_ZERO_SPACES) {                            \
-       url_flags_out |= RSPAMD_URL_FLAG_ZW_SPACES;                                \
-     }                                                                            \
-     if (norm_res & (RSPAMD_UNICODE_NORM_ERROR)) {                                \
-       url_flags_out |= RSPAMD_URL_FLAG_OBSCURED;                                 \
-     }                                                                            \
-  } while(0)
-#ifdef  __cplusplus
+	do {                                                                          \
+		enum rspamd_utf8_normalise_result norm_res;                               \
+		norm_res = rspamd_normalise_unicode_inplace((input), (len_out));          \
+		if (norm_res & RSPAMD_UNICODE_NORM_UNNORMAL) {                            \
+			url_flags_out |= RSPAMD_URL_FLAG_UNNORMALISED;                        \
+		}                                                                         \
+		if (norm_res & RSPAMD_UNICODE_NORM_ZERO_SPACES) {                         \
+			url_flags_out |= RSPAMD_URL_FLAG_ZW_SPACES;                           \
+		}                                                                         \
+		if (norm_res & (RSPAMD_UNICODE_NORM_ERROR)) {                             \
+			url_flags_out |= RSPAMD_URL_FLAG_OBSCURED;                            \
+		}                                                                         \
+	} while (0)
+#ifdef __cplusplus
 }
 #endif
 
