@@ -41,29 +41,29 @@
 #define MEMPOOL_STR_FUNC G_STRFUNC
 #endif
 
-#ifdef  __cplusplus
+#ifdef __cplusplus
 extern "C" {
 #endif
 
 struct f_str_s;
 
 #ifdef __has_attribute
-#  if __has_attribute(alloc_size)
-#    define RSPAMD_ATTR_ALLOC_SIZE(pos) __attribute__((alloc_size(pos)))
-#  else
-#    define RSPAMD_ATTR_ALLOC_SIZE(pos)
-#  endif
+#if __has_attribute(alloc_size)
+#define RSPAMD_ATTR_ALLOC_SIZE(pos) __attribute__((alloc_size(pos)))
+#else
+#define RSPAMD_ATTR_ALLOC_SIZE(pos)
+#endif
 
-#  if __has_attribute(assume_aligned)
-#    define RSPAMD_ATTR_ALLOC_ALIGN(al) __attribute__((assume_aligned(al)))
-#  else
-#    define RSPAMD_ATTR_ALLOC_ALIGN(al)
-#  endif
-#  if __has_attribute(returns_nonnull)
-#    define RSPAMD_ATTR_RETURNS_NONNUL __attribute__((returns_nonnull))
-#  else
-#    define RSPAMD_ATTR_RETURNS_NONNUL
-#  endif
+#if __has_attribute(assume_aligned)
+#define RSPAMD_ATTR_ALLOC_ALIGN(al) __attribute__((assume_aligned(al)))
+#else
+#define RSPAMD_ATTR_ALLOC_ALIGN(al)
+#endif
+#if __has_attribute(returns_nonnull)
+#define RSPAMD_ATTR_RETURNS_NONNUL __attribute__((returns_nonnull))
+#else
+#define RSPAMD_ATTR_RETURNS_NONNUL
+#endif
 #else
 #define RSPAMD_ATTR_ALLOC_SIZE(pos)
 #define RSPAMD_ATTR_ALLOC_ALIGN(al)
@@ -73,12 +73,12 @@ struct f_str_s;
 #define MEMPOOL_TAG_LEN 20
 #define MEMPOOL_UID_LEN 20
 /* All pointers are aligned as this variable */
-#define MIN_MEM_ALIGNMENT   G_MEM_ALIGN
+#define MIN_MEM_ALIGNMENT G_MEM_ALIGN
 
 /**
  * Destructor type definition
  */
-typedef void (*rspamd_mempool_destruct_t) (void *ptr);
+typedef void (*rspamd_mempool_destruct_t)(void *ptr);
 
 /**
  * Pool mutex structure
@@ -93,8 +93,8 @@ typedef struct memory_pool_mutex_s {
  * Rwlock for locking shared memory regions
  */
 typedef struct memory_pool_rwlock_s {
-	rspamd_mempool_mutex_t *__r_lock;                           /**< read mutex (private)								*/
-	rspamd_mempool_mutex_t *__w_lock;                           /**< write mutex (private)								*/
+	rspamd_mempool_mutex_t *__r_lock; /**< read mutex (private)								*/
+	rspamd_mempool_mutex_t *__w_lock; /**< write mutex (private)								*/
 } rspamd_mempool_rwlock_t;
 #else
 typedef pthread_mutex_t rspamd_mempool_mutex_t;
@@ -105,8 +105,8 @@ typedef pthread_rwlock_t rspamd_mempool_rwlock_t;
  * Tag to use for logging purposes
  */
 struct rspamd_mempool_tag {
-	gchar tagname[MEMPOOL_TAG_LEN];         /**< readable name							*/
-	gchar uid[MEMPOOL_UID_LEN];             /**< unique id								*/
+	gchar tagname[MEMPOOL_TAG_LEN]; /**< readable name							*/
+	gchar uid[MEMPOOL_UID_LEN];     /**< unique id								*/
 };
 
 enum rspamd_mempool_flags {
@@ -121,21 +121,21 @@ struct rspamd_mutex_s;
 struct rspamd_mempool_specific;
 typedef struct memory_pool_s {
 	struct rspamd_mempool_specific *priv;
-	struct rspamd_mempool_tag tag;          /**< memory pool tag						*/
+	struct rspamd_mempool_tag tag; /**< memory pool tag						*/
 } rspamd_mempool_t;
 
 /**
  * Statistics structure
  */
 typedef struct memory_pool_stat_s {
-	guint pools_allocated;              /**< total number of allocated pools					*/
-	guint pools_freed;                  /**< number of freed pools								*/
-	guint bytes_allocated;              /**< bytes that are allocated with pool allocator		*/
-	guint chunks_allocated;             /**< number of chunks that are allocated				*/
-	guint shared_chunks_allocated;      /**< shared chunks allocated							*/
-	guint chunks_freed;                 /**< chunks freed										*/
-	guint oversized_chunks;             /**< oversized chunks									*/
-	guint fragmented_size;                /**< fragmentation size								*/
+	guint pools_allocated;         /**< total number of allocated pools					*/
+	guint pools_freed;             /**< number of freed pools								*/
+	guint bytes_allocated;         /**< bytes that are allocated with pool allocator		*/
+	guint chunks_allocated;        /**< number of chunks that are allocated				*/
+	guint shared_chunks_allocated; /**< shared chunks allocated							*/
+	guint chunks_freed;            /**< chunks freed										*/
+	guint oversized_chunks;        /**< oversized chunks									*/
+	guint fragmented_size;         /**< fragmentation size								*/
 } rspamd_mempool_stat_t;
 
 
@@ -144,8 +144,8 @@ typedef struct memory_pool_stat_s {
  * @param size size of pool's page
  * @return new memory pool object
  */
-rspamd_mempool_t *rspamd_mempool_new_ (gsize size, const gchar *tag, gint flags,
-		const gchar *loc);
+rspamd_mempool_t *rspamd_mempool_new_(gsize size, const gchar *tag, gint flags,
+									  const gchar *loc);
 
 #define rspamd_mempool_new(size, tag, flags) \
 	rspamd_mempool_new_((size), (tag), (flags), G_STRLOC)
@@ -158,7 +158,7 @@ rspamd_mempool_t *rspamd_mempool_new_ (gsize size, const gchar *tag, gint flags,
  * @param size bytes to allocate
  * @return pointer to allocated object
  */
-void *rspamd_mempool_alloc_ (rspamd_mempool_t *pool, gsize size, gsize alignment, const gchar *loc)
+void *rspamd_mempool_alloc_(rspamd_mempool_t *pool, gsize size, gsize alignment, const gchar *loc)
 	RSPAMD_ATTR_ALLOC_SIZE(2) RSPAMD_ATTR_ALLOC_ALIGN(MIN_MEM_ALIGNMENT) RSPAMD_ATTR_RETURNS_NONNUL;
 /**
  * Allocates array handling potential integer overflow
@@ -169,26 +169,26 @@ void *rspamd_mempool_alloc_ (rspamd_mempool_t *pool, gsize size, gsize alignment
  * @param loc
  * @return
  */
-void *rspamd_mempool_alloc_array_ (rspamd_mempool_t *pool, gsize nmemb, gsize size, gsize alignment, const gchar *loc)
-RSPAMD_ATTR_ALLOC_SIZE(2) RSPAMD_ATTR_ALLOC_ALIGN(MIN_MEM_ALIGNMENT) RSPAMD_ATTR_RETURNS_NONNUL;
+void *rspamd_mempool_alloc_array_(rspamd_mempool_t *pool, gsize nmemb, gsize size, gsize alignment, const gchar *loc)
+	RSPAMD_ATTR_ALLOC_SIZE(2) RSPAMD_ATTR_ALLOC_ALIGN(MIN_MEM_ALIGNMENT) RSPAMD_ATTR_RETURNS_NONNUL;
 #define rspamd_mempool_alloc(pool, size) \
 	rspamd_mempool_alloc_((pool), (size), MIN_MEM_ALIGNMENT, (G_STRLOC))
 #define rspamd_mempool_alloc_array(pool, nmemb, size) \
 	rspamd_mempool_alloc_array_((pool), (nmemb), (size), MIN_MEM_ALIGNMENT, (G_STRLOC))
 #define rspamd_mempool_alloc_array_type(pool, nmemb, type) \
-	(type *)rspamd_mempool_alloc_array_((pool), (nmemb), sizeof(type), MIN_MEM_ALIGNMENT, (G_STRLOC))
-#define rspamd_mempool_alloc_type(pool, type) \
-	(type *)(rspamd_mempool_alloc_((pool), sizeof(type), \
-	MAX(MIN_MEM_ALIGNMENT, RSPAMD_ALIGNOF(type)), (G_STRLOC)))
+	(type *) rspamd_mempool_alloc_array_((pool), (nmemb), sizeof(type), MIN_MEM_ALIGNMENT, (G_STRLOC))
+#define rspamd_mempool_alloc_type(pool, type)             \
+	(type *) (rspamd_mempool_alloc_((pool), sizeof(type), \
+									MAX(MIN_MEM_ALIGNMENT, RSPAMD_ALIGNOF(type)), (G_STRLOC)))
 #define rspamd_mempool_alloc_buffer(pool, buflen) \
-	(char *)(rspamd_mempool_alloc_((pool), sizeof(char) * (buflen), MIN_MEM_ALIGNMENT, (G_STRLOC)))
+	(char *) (rspamd_mempool_alloc_((pool), sizeof(char) * (buflen), MIN_MEM_ALIGNMENT, (G_STRLOC)))
 /**
  * Notify external memory usage for memory pool
  * @param pool
  * @param size
  * @param loc
  */
-void rspamd_mempool_notify_alloc_ (rspamd_mempool_t *pool, gsize size, const gchar *loc);
+void rspamd_mempool_notify_alloc_(rspamd_mempool_t *pool, gsize size, const gchar *loc);
 #define rspamd_mempool_notify_alloc(pool, size) \
 	rspamd_mempool_notify_alloc_((pool), (size), (G_STRLOC))
 
@@ -198,13 +198,13 @@ void rspamd_mempool_notify_alloc_ (rspamd_mempool_t *pool, gsize size, const gch
  * @param size bytes to allocate
  * @return pointer to allocated object
  */
-void *rspamd_mempool_alloc0_ (rspamd_mempool_t *pool, gsize size, gsize alignment, const gchar *loc)
+void *rspamd_mempool_alloc0_(rspamd_mempool_t *pool, gsize size, gsize alignment, const gchar *loc)
 	RSPAMD_ATTR_ALLOC_SIZE(2) RSPAMD_ATTR_ALLOC_ALIGN(MIN_MEM_ALIGNMENT) RSPAMD_ATTR_RETURNS_NONNUL;
 #define rspamd_mempool_alloc0(pool, size) \
 	rspamd_mempool_alloc0_((pool), (size), MIN_MEM_ALIGNMENT, (G_STRLOC))
-#define rspamd_mempool_alloc0_type(pool, type) \
-	(type *)(rspamd_mempool_alloc0_((pool), sizeof(type), \
-		MAX(MIN_MEM_ALIGNMENT, RSPAMD_ALIGNOF(type)), (G_STRLOC)))
+#define rspamd_mempool_alloc0_type(pool, type)             \
+	(type *) (rspamd_mempool_alloc0_((pool), sizeof(type), \
+									 MAX(MIN_MEM_ALIGNMENT, RSPAMD_ALIGNOF(type)), (G_STRLOC)))
 
 /**
  * Make a copy of string in pool
@@ -212,10 +212,10 @@ void *rspamd_mempool_alloc0_ (rspamd_mempool_t *pool, gsize size, gsize alignmen
  * @param src source string
  * @return pointer to newly created string that is copy of src
  */
-gchar *rspamd_mempool_strdup_ (rspamd_mempool_t *pool, const gchar *src, const gchar *loc)
+gchar *rspamd_mempool_strdup_(rspamd_mempool_t *pool, const gchar *src, const gchar *loc)
 	RSPAMD_ATTR_ALLOC_ALIGN(MIN_MEM_ALIGNMENT);
 #define rspamd_mempool_strdup(pool, src) \
-	rspamd_mempool_strdup_ ((pool), (src), (G_STRLOC))
+	rspamd_mempool_strdup_((pool), (src), (G_STRLOC))
 
 struct f_str_tok;
 
@@ -225,33 +225,33 @@ struct f_str_tok;
  * @param src source string
  * @return pointer to newly created string that is copy of src
  */
-gchar *rspamd_mempool_ftokdup_ (rspamd_mempool_t *pool,
-								const struct f_str_tok *src,
-								const gchar *loc)
-RSPAMD_ATTR_ALLOC_ALIGN(MIN_MEM_ALIGNMENT);
+gchar *rspamd_mempool_ftokdup_(rspamd_mempool_t *pool,
+							   const struct f_str_tok *src,
+							   const gchar *loc)
+	RSPAMD_ATTR_ALLOC_ALIGN(MIN_MEM_ALIGNMENT);
 #define rspamd_mempool_ftokdup(pool, src) \
-	rspamd_mempool_ftokdup_ ((pool), (src), (G_STRLOC))
+	rspamd_mempool_ftokdup_((pool), (src), (G_STRLOC))
 
 /**
  * Allocate piece of shared memory
  * @param pool memory pool object
  * @param size bytes to allocate
  */
-void *rspamd_mempool_alloc_shared_ (rspamd_mempool_t *pool, gsize size, gsize alignment, const gchar *loc)
+void *rspamd_mempool_alloc_shared_(rspamd_mempool_t *pool, gsize size, gsize alignment, const gchar *loc)
 	RSPAMD_ATTR_ALLOC_SIZE(2) RSPAMD_ATTR_ALLOC_ALIGN(MIN_MEM_ALIGNMENT) RSPAMD_ATTR_RETURNS_NONNUL;
 #define rspamd_mempool_alloc_shared(pool, size) \
 	rspamd_mempool_alloc_shared_((pool), (size), MIN_MEM_ALIGNMENT, (G_STRLOC))
-#define rspamd_mempool_alloc_shared_type(pool, type) \
-	(type *)(rspamd_mempool_alloc_shared_((pool), sizeof(type), \
-		MAX(MIN_MEM_ALIGNMENT, RSPAMD_ALIGNOF(type)), (G_STRLOC)))
+#define rspamd_mempool_alloc_shared_type(pool, type)             \
+	(type *) (rspamd_mempool_alloc_shared_((pool), sizeof(type), \
+										   MAX(MIN_MEM_ALIGNMENT, RSPAMD_ALIGNOF(type)), (G_STRLOC)))
 
-void *rspamd_mempool_alloc0_shared_ (rspamd_mempool_t *pool, gsize size, gsize alignment, const gchar *loc)
+void *rspamd_mempool_alloc0_shared_(rspamd_mempool_t *pool, gsize size, gsize alignment, const gchar *loc)
 	RSPAMD_ATTR_ALLOC_SIZE(2) RSPAMD_ATTR_ALLOC_ALIGN(MIN_MEM_ALIGNMENT) RSPAMD_ATTR_RETURNS_NONNUL;
 #define rspamd_mempool_alloc0_shared(pool, size) \
 	rspamd_mempool_alloc0_shared_((pool), (size), MIN_MEM_ALIGNMENT, (G_STRLOC))
-#define rspamd_mempool_alloc0_shared_type(pool, type) \
-	(type *)(rspamd_mempool_alloc0_shared_((pool), sizeof(type), \
-		MAX(MIN_MEM_ALIGNMENT, RSPAMD_ALIGNOF(type)), (G_STRLOC)))
+#define rspamd_mempool_alloc0_shared_type(pool, type)             \
+	(type *) (rspamd_mempool_alloc0_shared_((pool), sizeof(type), \
+											MAX(MIN_MEM_ALIGNMENT, RSPAMD_ALIGNOF(type)), (G_STRLOC)))
 
 /**
  * Add destructor callback to pool
@@ -259,15 +259,15 @@ void *rspamd_mempool_alloc0_shared_ (rspamd_mempool_t *pool, gsize size, gsize a
  * @param func pointer to function-destructor
  * @param data pointer to data that would be passed to destructor
  */
-void rspamd_mempool_add_destructor_full (rspamd_mempool_t *pool,
-										 rspamd_mempool_destruct_t func,
-										 void *data,
-										 const gchar *function,
-										 const gchar *line);
+void rspamd_mempool_add_destructor_full(rspamd_mempool_t *pool,
+										rspamd_mempool_destruct_t func,
+										void *data,
+										const gchar *function,
+										const gchar *line);
 
 /* Macros for common usage */
 #define rspamd_mempool_add_destructor(pool, func, data) \
-    rspamd_mempool_add_destructor_full (pool, func, data, (MEMPOOL_STR_FUNC), (G_STRLOC))
+	rspamd_mempool_add_destructor_full(pool, func, data, (MEMPOOL_STR_FUNC), (G_STRLOC))
 
 /**
  * Replace destructor callback to pool for specified pointer
@@ -276,83 +276,83 @@ void rspamd_mempool_add_destructor_full (rspamd_mempool_t *pool,
  * @param old_data pointer to old data
  * @param new_data pointer to data that would be passed to destructor
  */
-void rspamd_mempool_replace_destructor (rspamd_mempool_t *pool,
-										rspamd_mempool_destruct_t func,
-										void *old_data, void *new_data);
+void rspamd_mempool_replace_destructor(rspamd_mempool_t *pool,
+									   rspamd_mempool_destruct_t func,
+									   void *old_data, void *new_data);
 
 /**
  * Calls all destructors associated with the specific memory pool without removing
  * of the pool itself
  * @param pool
  */
-void rspamd_mempool_destructors_enforce (rspamd_mempool_t *pool);
+void rspamd_mempool_destructors_enforce(rspamd_mempool_t *pool);
 
 /**
  * Delete pool, free all its chunks and call destructors chain
  * @param pool memory pool object
  */
-void rspamd_mempool_delete (rspamd_mempool_t *pool);
+void rspamd_mempool_delete(rspamd_mempool_t *pool);
 
 /**
  * Get new mutex from pool (allocated in shared memory)
  * @param pool memory pool object
  * @return mutex object
  */
-rspamd_mempool_mutex_t *rspamd_mempool_get_mutex (rspamd_mempool_t *pool);
+rspamd_mempool_mutex_t *rspamd_mempool_get_mutex(rspamd_mempool_t *pool);
 
 /**
  * Lock mutex
  * @param mutex mutex to lock
  */
-void rspamd_mempool_lock_mutex (rspamd_mempool_mutex_t *mutex);
+void rspamd_mempool_lock_mutex(rspamd_mempool_mutex_t *mutex);
 
 /**
  * Unlock mutex
  * @param mutex mutex to unlock
  */
-void rspamd_mempool_unlock_mutex (rspamd_mempool_mutex_t *mutex);
+void rspamd_mempool_unlock_mutex(rspamd_mempool_mutex_t *mutex);
 
 /**
  * Create new rwlock and place it in shared memory
  * @param pool memory pool object
  * @return rwlock object
  */
-rspamd_mempool_rwlock_t *rspamd_mempool_get_rwlock (rspamd_mempool_t *pool);
+rspamd_mempool_rwlock_t *rspamd_mempool_get_rwlock(rspamd_mempool_t *pool);
 
 /**
  * Acquire read lock
  * @param lock rwlock object
  */
-void rspamd_mempool_rlock_rwlock (rspamd_mempool_rwlock_t *lock);
+void rspamd_mempool_rlock_rwlock(rspamd_mempool_rwlock_t *lock);
 
 /**
  * Acquire write lock
  * @param lock rwlock object
  */
-void rspamd_mempool_wlock_rwlock (rspamd_mempool_rwlock_t *lock);
+void rspamd_mempool_wlock_rwlock(rspamd_mempool_rwlock_t *lock);
 
 /**
  * Release read lock
  * @param lock rwlock object
  */
-void rspamd_mempool_runlock_rwlock (rspamd_mempool_rwlock_t *lock);
+void rspamd_mempool_runlock_rwlock(rspamd_mempool_rwlock_t *lock);
 
 /**
  * Release write lock
  * @param lock rwlock object
  */
-void rspamd_mempool_wunlock_rwlock (rspamd_mempool_rwlock_t *lock);
+void rspamd_mempool_wunlock_rwlock(rspamd_mempool_rwlock_t *lock);
 
 /**
  * Get pool allocator statistics
  * @param st stat pool struct
  */
-void rspamd_mempool_stat (rspamd_mempool_stat_t *st);
+void rspamd_mempool_stat(rspamd_mempool_stat_t *st);
 
 /**
  * Reset memory pool stat
  */
-void rspamd_mempool_stat_reset (void);
+void rspamd_mempool_stat_reset(void);
 
 /**
  * Get optimal pool size based on page size for this system
@@ -360,10 +360,10 @@ void rspamd_mempool_stat_reset (void);
  */
 #define rspamd_mempool_suggest_size() rspamd_mempool_suggest_size_(G_STRLOC)
 
-gsize rspamd_mempool_suggest_size_ (const char *loc);
+gsize rspamd_mempool_suggest_size_(const char *loc);
 
-gsize rspamd_mempool_get_used_size (rspamd_mempool_t *pool);
-gsize rspamd_mempool_get_wasted_size (rspamd_mempool_t *pool);
+gsize rspamd_mempool_get_used_size(rspamd_mempool_t *pool);
+gsize rspamd_mempool_get_wasted_size(rspamd_mempool_t *pool);
 
 /**
  * Set memory pool variable
@@ -372,10 +372,10 @@ gsize rspamd_mempool_get_wasted_size (rspamd_mempool_t *pool);
  * @param gpointer value of variable
  * @param destructor pointer to function-destructor
  */
-void rspamd_mempool_set_variable (rspamd_mempool_t *pool,
-								  const gchar *name,
-								  gpointer value,
-								  rspamd_mempool_destruct_t destructor);
+void rspamd_mempool_set_variable(rspamd_mempool_t *pool,
+								 const gchar *name,
+								 gpointer value,
+								 rspamd_mempool_destruct_t destructor);
 
 /**
  * Get memory pool variable
@@ -383,16 +383,16 @@ void rspamd_mempool_set_variable (rspamd_mempool_t *pool,
  * @param name name of variable
  * @return NULL or pointer to variable data
  */
-gpointer rspamd_mempool_get_variable (rspamd_mempool_t *pool,
-									  const gchar *name);
+gpointer rspamd_mempool_get_variable(rspamd_mempool_t *pool,
+									 const gchar *name);
 
 /**
  * Removes variable from memory pool
  * @param pool memory pool object
  * @param name name of variable
  */
-void rspamd_mempool_remove_variable (rspamd_mempool_t *pool,
-									 const gchar *name);
+void rspamd_mempool_remove_variable(rspamd_mempool_t *pool,
+									const gchar *name);
 
 /**
  * Prepend element to a list creating it in the memory pool
@@ -400,8 +400,8 @@ void rspamd_mempool_remove_variable (rspamd_mempool_t *pool,
  * @param p
  * @return
  */
-GList *rspamd_mempool_glist_prepend (rspamd_mempool_t *pool,
-									 GList *l, gpointer p) G_GNUC_WARN_UNUSED_RESULT;
+GList *rspamd_mempool_glist_prepend(rspamd_mempool_t *pool,
+									GList *l, gpointer p) G_GNUC_WARN_UNUSED_RESULT;
 
 /**
  * Append element to a list creating it in the memory pool
@@ -409,14 +409,14 @@ GList *rspamd_mempool_glist_prepend (rspamd_mempool_t *pool,
  * @param p
  * @return
  */
-GList *rspamd_mempool_glist_append (rspamd_mempool_t *pool,
-									GList *l, gpointer p) G_GNUC_WARN_UNUSED_RESULT;
+GList *rspamd_mempool_glist_append(rspamd_mempool_t *pool,
+								   GList *l, gpointer p) G_GNUC_WARN_UNUSED_RESULT;
 
-#ifdef  __cplusplus
+#ifdef __cplusplus
 }
 #endif
 
-#ifdef  __cplusplus
+#ifdef __cplusplus
 #include <stdexcept> /* For std::runtime_error */
 
 namespace rspamd {
@@ -428,23 +428,31 @@ public:
 
 	mempool_allocator() = delete;
 	template<class U>
-	mempool_allocator(const mempool_allocator<U> &other) : pool(other.pool) {}
-	mempool_allocator(rspamd_mempool_t *_pool) : pool(_pool) {}
-	[[nodiscard]] constexpr T* allocate(std::size_t n)
+	mempool_allocator(const mempool_allocator<U> &other)
+		: pool(other.pool)
+	{
+	}
+	mempool_allocator(rspamd_mempool_t *_pool)
+		: pool(_pool)
+	{
+	}
+	[[nodiscard]] constexpr T *allocate(std::size_t n)
 	{
 		if (G_MAXSIZE / 2 / sizeof(T) > n) {
 			throw std::runtime_error("integer overflow");
 		}
-		return reinterpret_cast<T*>(rspamd_mempool_alloc(pool, n * sizeof(T)));
+		return reinterpret_cast<T *>(rspamd_mempool_alloc(pool, n * sizeof(T)));
 	}
-	constexpr void deallocate(T* p, std::size_t n) {
+	constexpr void deallocate(T *p, std::size_t n)
+	{
 		/* Do nothing */
 	}
+
 private:
 	rspamd_mempool_t *pool;
 };
 
-}
+}// namespace rspamd
 #endif
 
 #endif
