@@ -45,158 +45,170 @@ local settings = {
   extension_map = { -- extension -> mime_type
     html = 'text/html',
     htm = 'text/html',
-    txt = 'text/plain',
-    pdf = 'application/pdf'
+    pdf = 'application/pdf',
+    shtm = 'text/html',
+    shtml = 'text/html',
+    txt = 'text/plain'
   },
 
   bad_extensions = {
     bat = 2,
+    chm = 4,
     com = 2,
     exe = 1,
+    hta = 2,
     iso = 4,
     jar = 2,
     lnk = 4,
     scr = 4,
+    -- In contrast to HTML MIME parts, dedicated HTML attachments are considered harmful
+    htm = 1,
+    html = 1,
+    shtm = 1,
+    shtml = 1,
     -- Have you ever seen that in legit email?
     ace = 4,
     arj = 2,
+    asx = 2,
     cab = 3,
+    sfx = 2,
+    vst = 2,
+    vss = 2,
     -- Additional bad extensions from Gmail
-    ade = 2,
-    adp = 2,
-    chm = 2,
-    cmd = 2,
-    cpl = 2,
-    ins = 2,
-    isp = 2,
-    js = 2,
-    jse = 2,
-    lib = 2,
-    mde = 2,
-    msc = 2,
-    msi = 2,
-    msp = 2,
-    mst = 2,
-    nsh = 2,
-    pif = 2,
-    sct = 2,
-    shb = 2,
-    sys = 2,
-    vb = 2,
-    vbe = 2,
-    vbs = 2,
-    vxd = 2,
-    wsc = 2,
-    wsh = 2,
+    ade = 4,
+    adp = 4,
+    cmd = 4,
+    cpl = 4,
+    ins = 4,
+    isp = 4,
+    js = 4,
+    jse = 4,
+    lib = 4,
+    mde = 4,
+    msc = 4,
+    msi = 4,
+    msp = 4,
+    mst = 4,
+    nsh = 4,
+    pif = 4,
+    sct = 4,
+    shb = 4,
+    sys = 4,
+    vb = 4,
+    vbe = 4,
+    vbs = 4,
+    vxd = 4,
+    wsc = 4,
+    wsh = 4,
     -- Additional bad extensions from Outlook
-    app = 2,
-    asp = 2,
-    bas = 2,
-    cnt = 2,
-    csh = 2,
-    diagcab = 2,
-    fxp = 2,
-    gadget = 2,
-    grp = 2,
-    hlp = 2,
-    hpj = 2,
-    inf = 2,
-    its = 2,
-    jnlp = 2,
-    ksh = 2,
-    mad = 2,
-    maf = 2,
-    mag = 2,
-    mam = 2,
-    maq = 2,
-    mar = 2,
-    mas = 2,
-    mat = 2,
-    mau = 2,
-    mav = 2,
-    maw = 2,
-    mcf = 2,
-    mda = 2,
-    mdb = 2,
-    mdt = 2,
-    mdw = 2,
-    mdz = 2,
-    msh = 2,
-    msh1 = 2,
-    msh2 = 2,
-    mshxml = 2,
-    msh1xml = 2,
-    msh2xml = 2,
-    msu = 2,
-    ops = 2,
-    osd = 2,
-    pcd = 2,
-    pl = 2,
-    plg = 2,
-    prf = 2,
-    prg = 2,
-    printerexport = 2,
-    ps1 = 2,
-    ps1xml = 2,
-    ps2 = 2,
-    ps2xml = 2,
-    psc1 = 2,
-    psc2 = 2,
-    psd1 = 2,
-    psdm1 = 2,
-    pst = 2,
-    reg = 2,
-    scf = 2,
-    shs = 2,
-    theme = 2,
-    url = 2,
-    vbp = 2,
-    vsmacros = 2,
-    vsw = 2,
-    webpnp = 2,
-    website = 2,
-    ws = 2,
-    xbap = 2,
-    xll = 2,
-    xnk = 2,
+    app = 4,
+    asp = 4,
+    bas = 4,
+    cnt = 4,
+    csh = 4,
+    diagcab = 4,
+    fxp = 4,
+    gadget = 4,
+    grp = 4,
+    hlp = 4,
+    hpj = 4,
+    inf = 4,
+    its = 4,
+    jnlp = 4,
+    ksh = 4,
+    mad = 4,
+    maf = 4,
+    mag = 4,
+    mam = 4,
+    maq = 4,
+    mar = 4,
+    mas = 4,
+    mat = 4,
+    mau = 4,
+    mav = 4,
+    maw = 4,
+    mcf = 4,
+    mda = 4,
+    mdb = 4,
+    mdt = 4,
+    mdw = 4,
+    mdz = 4,
+    msh = 4,
+    msh1 = 4,
+    msh2 = 4,
+    mshxml = 4,
+    msh1xml = 4,
+    msh2xml = 4,
+    msu = 4,
+    ops = 4,
+    osd = 4,
+    pcd = 4,
+    pl = 4,
+    plg = 4,
+    prf = 4,
+    prg = 4,
+    printerexport = 4,
+    ps1 = 4,
+    ps1xml = 4,
+    ps2 = 4,
+    ps2xml = 4,
+    psc1 = 4,
+    psc2 = 4,
+    psd1 = 4,
+    psdm1 = 4,
+    pst = 4,
+    reg = 4,
+    scf = 4,
+    shs = 4,
+    theme = 4,
+    url = 4,
+    vbp = 4,
+    vsmacros = 4,
+    vsw = 4,
+    webpnp = 4,
+    website = 4,
+    ws = 4,
+    xbap = 4,
+    xll = 4,
+    xnk = 4,
   },
 
   -- Something that should not be in archive
   bad_archive_extensions = {
-    pptx = 0.1,
     docx = 0.1,
-    xlsx = 0.1,
-    pdf = 0.1,
+    hta = 4,
     jar = 3,
     js = 0.5,
+    pdf = 0.1,
+    pptx = 0.1,
     vbs = 4,
     wsf = 4,
-    hta = 4,
+    xlsx = 0.1,
   },
 
   archive_extensions = {
-    zip = 1,
-    arj = 1,
-    rar = 1,
-    ace = 1,
     ['7z'] = 1,
-    cab = 1,
-    bz2 = 1,
-    egg = 1,
+    ace = 1,
     alz = 1,
-    xz = 1,
+    arj = 1,
+    bz2 = 1,
+    cab = 1,
+    egg = 1,
     lz = 1,
+    rar = 1,
+    xz = 1,
+    zip = 1,
   },
 
   -- Not really archives
   archive_exceptions = {
-    odt = true,
-    ods = true,
-    odp = true,
     docx = true,
-    xlsx = true,
+    odp = true,
+    ods = true,
+    odt = true,
     pptx = true,
     vsdx = true,
+    xlsx = true,
     -- jar = true,
   },
 
